#include <stdio.h>
#include "lock.h"

main ()
{
  Lock *lock = (Lock *) malloc (sizeof(Lock));

  lock->value = 0;

  acquire (lock);
  printf ("%d\n", lock->value);
  release (lock);
  printf ("%d\n", lock->value);
}
